@@ -4,8 +4,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_ALTERNATELABEL_H
-#define EVENTVIEWS_ALTERNATELABEL_H
+#pragma once
 
 #include <QLabel>
 
@@ -20,7 +19,7 @@ public:
 
     enum TextType { Short = 0, Long = 1, Extensive = 2 };
 
-    Q_REQUIRED_RESULT TextType largestFittingTextType() const;
+    [[nodiscard]] TextType largestFittingTextType() const;
     void setFixedType(TextType type);
 
 public Q_SLOTS:
@@ -41,5 +40,3 @@ private:
     int getIndent() const;
 };
 }
-
-#endif
