@@ -374,8 +374,8 @@ QString TimeLabels::headerToolTip() const
     toolTip += i18nc("heading for timezone display name", "<i>Name:</i> %1", mTimezone.displayName(now, QTimeZone::LongName));
     toolTip += QLatin1String("<br/>");
 
-    if (mTimezone.country() != QLocale::AnyCountry) {
-        toolTip += i18nc("heading for timezone country", "<i>Country:</i> %1", QLocale::countryToString(mTimezone.country()));
+    if (mTimezone.territory() != QLocale::AnyCountry) {
+        toolTip += i18nc("heading for timezone country", "<i>Country:</i> %1", QLocale::territoryToString(mTimezone.territory()));
         toolTip += QLatin1String("<br/>");
     }
 
@@ -422,3 +422,5 @@ bool TimeLabels::event(QEvent *event)
     }
     return QWidget::event(event);
 }
+
+#include "moc_timelabels.cpp"
