@@ -8,11 +8,11 @@
 #include "calendarview_debug.h"
 #include "prefs.h"
 
-#include <Collection>
-#include <Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
-#include <AkonadiCore/CollectionColorAttribute>
-#include <AkonadiCore/CollectionModifyJob>
+#include <Akonadi/CollectionColorAttribute>
+#include <Akonadi/CollectionModifyJob>
 
 #include <QIcon>
 #include <QPixmap>
@@ -42,7 +42,7 @@ void EventViews::setResourceColor(const Akonadi::Collection &coll, const QColor
     if (colorAttr) {
         colorAttr->setColor(color);
         auto job = new Akonadi::CollectionModifyJob(collection, nullptr);
-        QObject::connect(job, &Akonadi::CollectionModifyJob::result, [=]() {
+        QObject::connect(job, &Akonadi::CollectionModifyJob::result, [job]() {
             if (job->error()) {
                 qCWarning(CALENDARVIEW_LOG) << "Failed to set CollectionColorAttribute:" << job->errorString();
             }
