@@ -13,7 +13,9 @@
 #include "prefs_base.h" // Ugly, but needed for the Enums
 
 #include <Akonadi/CalendarUtils>
+#include <Akonadi/EntityTreeModel>
 #include <Akonadi/IncidenceChanger>
+#include <Akonadi/TagCache>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
@@ -282,7 +284,7 @@ QList<MonthGraphicsItem *> EventViews::MonthItem::monthGraphicsItems() const
 //-----------------------------------------------------------------
 // INCIDENCEMONTHITEM
 IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene,
-                                       const Akonadi::ETMCalendar::Ptr &calendar,
+                                       const Akonadi::CollectionCalendar::Ptr &calendar,
                                        const Akonadi::Item &aitem,
                                        const KCalendarCore::Incidence::Ptr &incidence,
                                        QDate recurStartDate)
@@ -375,12 +377,12 @@ bool IncidenceMonthItem::allDay() const
 
 bool IncidenceMonthItem::isMoveable() const
 {
-    return monthScene()->mMonthView->calendar()->hasRight(akonadiItem(), Akonadi::Collection::CanChangeItem);
+    return mCalendar->hasRight(Akonadi::Collection::CanChangeItem);
 }
 
 bool IncidenceMonthItem::isResizable() const
 {
-    return mIsEvent && monthScene()->mMonthView->calendar()->hasRight(akonadiItem(), Akonadi::Collection::CanChangeItem);
+    return mCalendar->hasRight(Akonadi::Collection::CanChangeItem);
 }
 
 void IncidenceMonthItem::finalizeMove(const QDate &newStartDate)
@@ -439,10 +441,10 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
                 changer->createIncidence(newIncidence, item.parentCollection(), parentWidget());
                 changer->endAtomicOperation();
             } else {
-                KMessageBox::sorry(parentWidget(),
+                KMessageBox::error(parentWidget(),
                                    i18n("Unable to add the exception item to the calendar. "
                                         "No change will be done."),
-                                   i18n("Error Occurred"));
+                                   i18nc("@title:window", "Error Occurred"));
             }
             break;
         }
@@ -498,15 +500,15 @@ QString IncidenceMonthItem::text(bool end) const
 
 QString IncidenceMonthItem::toolTipText(const QDate &date) const
 {
-    return KCalUtils::IncidenceFormatter::toolTipStr(Akonadi::CalendarUtils::displayName(mCalendar.data(), akonadiItem().parentCollection()),
+    return KCalUtils::IncidenceFormatter::toolTipStr(Akonadi::CalendarUtils::displayName(mCalendar->model(), akonadiItem().parentCollection()),
                                                      mIncidence,
                                                      date,
                                                      true);
 }
 
-QVector<QPixmap> IncidenceMonthItem::icons() const
+QList<QPixmap> IncidenceMonthItem::icons() const
 {
-    QVector<QPixmap> ret;
+    QList<QPixmap> ret;
 
     if (!mIncidence) {
         return ret;
@@ -554,7 +556,7 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
         }
     }
 
-    if (icons.contains(EventView::ReadOnlyIcon) && !monthScene()->mMonthView->calendar()->hasRight(item, Akonadi::Collection::CanChangeItem) && !specialEvent) {
+    if (icons.contains(EventView::ReadOnlyIcon) && !mCalendar->hasRight(Akonadi::Collection::CanChangeItem) && !specialEvent) {
         ret << monthScene()->readonlyPixmap();
     }
 
@@ -577,14 +579,14 @@ QColor IncidenceMonthItem::catColor() const
     const auto &prefs = monthScene()->monthView()->preferences();
 
     const auto &categories = mIncidence->categories();
-    if (categories.isEmpty() || !CalendarSupport::KCalPrefs::instance()->hasCategoryColor(categories.first())) {
+    if (categories.isEmpty() || !Akonadi::TagCache::instance()->tagColor(categories.first()).isValid()) {
         const auto &colorPreference = prefs->monthViewColors();
         if (colorPreference == PrefsBase::CategoryOnly) {
             return CalendarSupport::KCalPrefs::instance()->unsetCategoryColor();
         }
         return EventViews::resourceColor(akonadiItem(), prefs);
     }
-    return CalendarSupport::KCalPrefs::instance()->categoryColor(categories.first());
+    return Akonadi::TagCache::instance()->tagColor(categories.first());
 }
 
 QColor IncidenceMonthItem::bgColor() const
@@ -626,7 +628,7 @@ QColor IncidenceMonthItem::frameColor() const
 Akonadi::Item IncidenceMonthItem::akonadiItem() const
 {
     if (mIncidence) {
-        return monthScene()->mMonthView->calendar()->item(mIncidence);
+        return mCalendar->item(mIncidence);
     } else {
         return {};
     }
@@ -642,6 +644,11 @@ Akonadi::Item::Id IncidenceMonthItem::akonadiItemId() const
     return mAkonadiItemId;
 }
 
+Akonadi::CollectionCalendar::Ptr IncidenceMonthItem::calendar() const
+{
+    return mCalendar;
+}
+
 void IncidenceMonthItem::setNewDates(const KCalendarCore::Incidence::Ptr &incidence, int startOffset, int endOffset)
 {
     if (mIsTodo) {
@@ -716,9 +723,9 @@ void HolidayMonthItem::finalizeResize(const QDate &newStartDate, const QDate &ne
     Q_ASSERT(false);
 }
 
-QVector<QPixmap> HolidayMonthItem::icons() const
+QList<QPixmap> HolidayMonthItem::icons() const
 {
-    QVector<QPixmap> ret;
+    QList<QPixmap> ret;
     ret << monthScene()->holidayPixmap();
 
     return ret;
@@ -736,3 +743,5 @@ QColor HolidayMonthItem::frameColor() const
 {
     return Qt::black;
 }
+
+#include "moc_monthitem.cpp"
