@@ -323,7 +323,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
                                         "flat list instead of a hierarchical tree; the parental "
                                         "relationships are removed in the display."));
 
-    connect(mFlatViewButton, &QToolButton::toggled, this, [=](bool flatView) {
+    connect(mFlatViewButton, &QToolButton::toggled, this, [this](bool flatView) {
         setFlatView(flatView, true);
     });
     if (mFullViewButton) {
@@ -415,7 +415,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
                                   i18nc("@action:inmenu", "Create Event from To-do"),
                                   this,
                                   qOverload<>(&TodoView::createEvent));
-    a->setObjectName(QStringLiteral("createevent"));
+    a->setObjectName(QLatin1StringView("createevent"));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
@@ -423,7 +423,7 @@ TodoView::TodoView(const EventViews::PrefsPtr &prefs, bool sidebarView, QWidget
                                   i18nc("@action:inmenu", "Create Note for To-do"),
                                   this,
                                   qOverload<>(&TodoView::createNote));
-    a->setObjectName(QStringLiteral("createnote"));
+    a->setObjectName(QLatin1StringView("createnote"));
     mItemPopupMenuReadWriteEntries << a;
     mItemPopupMenuItemOnlyEntries << a;
 
@@ -1321,3 +1321,5 @@ void TodoView::createNote()
 }
 
 #include "todoview.moc"
+
+#include "moc_todoview.cpp"
