@@ -24,9 +24,8 @@
 
 #include <QHBoxLayout>
 
-TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent)
+TodoViewQuickSearch::TodoViewQuickSearch(QWidget *parent)
     : QWidget(parent)
-    , mCalendar(calendar)
     , mSearchLine(new QLineEdit(this))
     , mCategoryCombo(new Akonadi::TagSelectionComboBox(this))
     , mPriorityCombo(new KPIM::KCheckComboBox(this))
@@ -84,13 +83,6 @@ TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calend
     fillPriorities();
 }
 
-void TodoViewQuickSearch::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
-{
-    if (calendar != mCalendar) {
-        mCalendar = calendar;
-    }
-}
-
 void TodoViewQuickSearch::reset()
 {
     mSearchLine->clear();
@@ -115,3 +107,5 @@ void TodoViewQuickSearch::fillPriorities()
     // TODO: Using the same method as for categories to fill mPriorityCombo
     CalendarSupport::CategoryHierarchyReaderQComboBox(mPriorityCombo).read(priorityValues);
 }
+
+#include "moc_todoviewquicksearch.cpp"
