@@ -11,13 +11,9 @@
 #include <QTimer>
 #include <QTreeView>
 
+class KDatePickerPopup;
 class QMenu;
 
-namespace CalendarSupport
-{
-    class KDatePickerPopup;
-}
-
 class TodoViewView : public QTreeView
 {
     Q_OBJECT
@@ -25,10 +21,10 @@ class TodoViewView : public QTreeView
 public:
     explicit TodoViewView(QWidget *parent = nullptr);
 
-    Q_REQUIRED_RESULT bool isEditing(const QModelIndex &index) const;
+    [[nodiscard]] bool isEditing(const QModelIndex &index) const;
 
-    Q_REQUIRED_RESULT bool eventFilter(QObject *watched, QEvent *event) override;
-    Q_REQUIRED_RESULT CalendarSupport::KDatePickerPopup *startPopupMenu();
+    [[nodiscard]] bool eventFilter(QObject *watched, QEvent *event) override;
+    [[nodiscard]] KDatePickerPopup *startPopupMenu();
 
 protected:
     QModelIndex moveCursor(CursorAction cursorAction, Qt::KeyboardModifiers modifiers) override;
@@ -45,7 +41,7 @@ private:
     bool mIgnoreNextMouseRelease = false;
 
     // TODO KF6: move this next to TodoView::mMovePopupMenu.
-    CalendarSupport::KDatePickerPopup *mStartPopupMenu = nullptr;
+    KDatePickerPopup *mStartPopupMenu = nullptr;
 
 Q_SIGNALS:
     void visibleColumnCountChanged();
@@ -54,4 +50,3 @@ private Q_SLOTS:
     void toggleColumnHidden(QAction *action);
     void expandParent();
 };
-
