@@ -7,40 +7,36 @@
 */
 
 #include "whatsnextview.h"
+#include "calendarview_debug.h"
 
 #include <Akonadi/CalendarUtils>
-#include <Akonadi/ETMCalendar>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
 
 #include <KCalUtils/IncidenceFormatter>
 
 #include <QBoxLayout>
+#include <QUrlQuery>
+
+#include <optional>
 
 using namespace EventViews;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void WhatsNextTextBrowser::setSource(const QUrl &name)
-#else
 void WhatsNextTextBrowser::doSetSource(const QUrl &name, QTextDocument::ResourceType type)
-#endif
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     Q_UNUSED(type);
-#endif
-    const QString uri = name.toString();
-    if (uri.startsWith(QLatin1String("event:"))) {
-        Q_EMIT showIncidence(uri);
-    } else if (uri.startsWith(QLatin1String("todo:"))) {
-        Q_EMIT showIncidence(uri);
+    if (name.scheme() == QLatin1String("event")) {
+        Q_EMIT showIncidence(name);
+    } else if (name.scheme() == QLatin1String("todo")) {
+        Q_EMIT showIncidence(name);
     } else {
-        QTextBrowser::setSource(QUrl(uri));
+        QTextBrowser::setSource(name);
     }
 }
 
 WhatsNextView::WhatsNextView(QWidget *parent)
     : EventView(parent)
+    , mView(new WhatsNextTextBrowser(this))
 {
-    mView = new WhatsNextTextBrowser(this);
     connect(mView, &WhatsNextTextBrowser::showIncidence, this, &WhatsNextView::showIncidence);
 
     QBoxLayout *topLayout = new QVBoxLayout(this);
@@ -90,9 +86,11 @@ void WhatsNextView::updateView()
     mText += QLatin1String("</h2>\n");
 
     KCalendarCore::Event::List events;
-    events = calendar()->events(mStartDate, mEndDate, QTimeZone::systemTimeZone(), false);
+    for (const auto &calendar : calendars()) {
+        events += calendar->events(mStartDate, mEndDate, QTimeZone::systemTimeZone(), false);
+    }
 
-    events = calendar()->sortEvents(std::move(events), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
+    events = KCalendarCore::Calendar::sortEvents(std::move(events), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
     if (!events.isEmpty()) {
         mText += QLatin1String("<p></p>");
         kil->loadIcon(QStringLiteral("view-calendar-day"), KIconLoader::NoGroup, 22, KIconLoader::DefaultState, QStringList(), &ipath);
@@ -102,8 +100,9 @@ void WhatsNextView::updateView()
         mText += i18n("Events:") + QLatin1String("</h2>\n");
         mText += QLatin1String("<table>\n");
         for (const KCalendarCore::Event::Ptr &ev : std::as_const(events)) {
+            const auto calendar = calendar3(ev);
             if (!ev->recurs()) {
-                appendEvent(ev);
+                appendEvent(calendar, ev);
             } else {
                 KCalendarCore::Recurrence *recur = ev->recurrence();
                 int duration = ev->dtStart().secsTo(ev->dtEnd());
@@ -111,7 +110,7 @@ void WhatsNextView::updateView()
                 QDateTime end = start.addSecs(duration);
                 QDateTime endDate(mEndDate, QTime(23, 59, 59), Qt::LocalTime);
                 if (end.date() >= mStartDate) {
-                    appendEvent(ev, start.toLocalTime(), end.toLocalTime());
+                    appendEvent(calendar, ev, start.toLocalTime(), end.toLocalTime());
                 }
                 const auto times = recur->timesInInterval(start, endDate);
                 int count = times.count();
@@ -124,7 +123,7 @@ void WhatsNextView::updateView()
                         --count; // list overflow
                     }
                     for (; i < count && times[i].date() <= mEndDate; ++i) {
-                        appendEvent(ev, times[i].toLocalTime());
+                        appendEvent(calendar, ev, times[i].toLocalTime());
                     }
                 }
             }
@@ -133,28 +132,33 @@ void WhatsNextView::updateView()
     }
 
     mTodos.clear();
-    KCalendarCore::Todo::List todos = calendar()->todos(KCalendarCore::TodoSortDueDate, KCalendarCore::SortDirectionAscending);
+    KCalendarCore::Todo::List todos;
+    for (const auto &calendar : calendars()) {
+        todos += calendar->todos(KCalendarCore::TodoSortDueDate, KCalendarCore::SortDirectionAscending);
+    }
     if (!todos.isEmpty()) {
         bool taskHeaderWasCreated = false;
         for (const KCalendarCore::Todo::Ptr &todo : std::as_const(todos)) {
+            const auto calendar = calendar3(todo);
             if (!todo->isCompleted() && todo->hasDueDate() && todo->dtDue().date() <= mEndDate) {
                 if (!taskHeaderWasCreated) {
                     createTaskRow(kil);
                     taskHeaderWasCreated = true;
                 }
-                appendTodo(todo);
+                appendTodo(calendar, todo);
             }
         }
         bool gotone = false;
         int priority = 1;
         while (!gotone && priority <= 9) {
             for (const KCalendarCore::Todo::Ptr &todo : std::as_const(todos)) {
+                const auto calendar = calendar3(todo);
                 if (!todo->isCompleted() && (todo->priority() == priority)) {
                     if (!taskHeaderWasCreated) {
                         createTaskRow(kil);
                         taskHeaderWasCreated = true;
                     }
-                    appendTodo(todo);
+                    appendTodo(calendar, todo);
                     gotone = true;
                 }
             }
@@ -167,8 +171,12 @@ void WhatsNextView::updateView()
 
     QStringList myEmails(CalendarSupport::KCalPrefs::instance()->allEmails());
     int replies = 0;
-    events = calendar()->events(QDate::currentDate(), QDate(2975, 12, 6), QTimeZone::systemTimeZone());
+    events.clear();
+    for (const auto &calendar : calendars()) {
+        events += calendar->events(QDate::currentDate(), QDate(2975, 12, 6), QTimeZone::systemTimeZone());
+    }
     for (const KCalendarCore::Event::Ptr &ev : std::as_const(events)) {
+        const auto calendar = calendar3(ev);
         KCalendarCore::Attendee me = ev->attendeeByMails(myEmails);
         if (!me.isNull()) {
             if (me.status() == KCalendarCore::Attendee::NeedsAction && me.RSVP()) {
@@ -182,12 +190,17 @@ void WhatsNextView::updateView()
                     mText += QLatin1String("<table>\n");
                 }
                 replies++;
-                appendEvent(ev);
+                appendEvent(calendar, ev);
             }
         }
     }
-    todos = calendar()->todos();
+
+    todos.clear();
+    for (const auto &calendar : calendars()) {
+        todos += calendar->todos();
+    }
     for (const KCalendarCore::Todo::Ptr &to : std::as_const(todos)) {
+        const auto calendar = calendar3(to);
         KCalendarCore::Attendee me = to->attendeeByMails(myEmails);
         if (!me.isNull()) {
             if (me.status() == KCalendarCore::Attendee::NeedsAction && me.RSVP()) {
@@ -201,7 +214,7 @@ void WhatsNextView::updateView()
                     mText += QLatin1String("<table>\n");
                 }
                 replies++;
-                appendEvent(to);
+                appendEvent(calendar, to);
             }
         }
     }
@@ -232,7 +245,10 @@ void WhatsNextView::changeIncidenceDisplay(const Akonadi::Item &, Akonadi::Incid
     updateView();
 }
 
-void WhatsNextView::appendEvent(const KCalendarCore::Incidence::Ptr &incidence, const QDateTime &start, const QDateTime &end)
+void WhatsNextView::appendEvent(const Akonadi::CollectionCalendar::Ptr &calendar,
+                                const KCalendarCore::Incidence::Ptr &incidence,
+                                const QDateTime &start,
+                                const QDateTime &end)
 {
     mText += QLatin1String("<tr><td><b>");
     if (const KCalendarCore::Event::Ptr event = incidence.dynamicCast<KCalendarCore::Event>()) {
@@ -267,28 +283,25 @@ void WhatsNextView::appendEvent(const KCalendarCore::Incidence::Ptr &incidence,
             }
         }
     }
-    mText += QLatin1String("</b></td><td><a ");
-    if (incidence->type() == KCalendarCore::Incidence::TypeEvent) {
-        mText += QLatin1String("href=\"event:");
-    }
-    if (incidence->type() == KCalendarCore::Incidence::TypeTodo) {
-        mText += QLatin1String("href=\"todo:");
-    }
-    mText += incidence->uid() + QLatin1String("\">");
-    mText += incidence->summary();
-    mText += QLatin1String("</a></td></tr>\n");
+    mText += QLatin1String("</b></td>");
+    const QString proto = incidence->type() == KCalendarCore::Incidence::TypeTodo ? QStringLiteral("todo") : QStringLiteral("event");
+    mText += QStringLiteral(R"(<td><a href="%1:%2?itemId=%3&calendarId=%5">%4</a></td>)")
+                 .arg(proto, incidence->uid(), incidence->customProperty("VOLATILE", "AKONADI-ID"), incidence->summary())
+                 .arg(calendar->collection().id());
+    mText += QLatin1String("</tr>\n");
 }
 
-void WhatsNextView::appendTodo(const KCalendarCore::Incidence::Ptr &incidence)
+void WhatsNextView::appendTodo(const Akonadi::CollectionCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Akonadi::Item aitem = calendar()->item(incidence);
+    Akonadi::Item aitem = calendar->item(incidence);
     if (mTodos.contains(aitem)) {
         return;
     }
     mTodos.append(aitem);
-    mText += QLatin1String("<li><a href=\"todo:") + incidence->uid() + QLatin1String("\">");
-    mText += incidence->summary();
-    mText += QLatin1String("</a>");
+    mText += QLatin1String("<li>");
+    mText += QStringLiteral(R"(<a href="todo:%1?itemId=%2&calendarId=%4">%3</a>)")
+                 .arg(incidence->uid(), incidence->customProperty("VOLATILE", "AKONADI-ID"), incidence->summary())
+                 .arg(calendar->collection().id());
 
     if (const KCalendarCore::Todo::Ptr todo = Akonadi::CalendarUtils::todo(aitem)) {
         if (todo->hasDueDate()) {
@@ -298,22 +311,46 @@ void WhatsNextView::appendTodo(const KCalendarCore::Incidence::Ptr &incidence)
     }
 }
 
-void WhatsNextView::showIncidence(const QString &uid)
+static std::optional<Akonadi::Item::Id> idFromQuery(const QUrlQuery &query, const QString &queryValue)
 {
-    Akonadi::Item item;
+    const auto strVal = query.queryItemValue(queryValue);
+    if (strVal.isEmpty()) {
+        return {};
+    }
 
-    Akonadi::ETMCalendar::Ptr cal = calendar();
-    if (!cal) {
+    bool ok = false;
+    const auto intVal = strVal.toLongLong(&ok);
+    if (!ok) {
+        return {};
+    }
+
+    return intVal;
+}
+
+void WhatsNextView::showIncidence(const QUrl &uri)
+{
+    QUrlQuery query(uri);
+    const auto itemId = idFromQuery(query, QStringLiteral("itemId"));
+    const auto calendarId = idFromQuery(query, QStringLiteral("calendarId"));
+
+    if (!itemId || !calendarId) {
+        qCWarning(CALENDARVIEW_LOG) << "Invalid URI:" << uri;
         return;
     }
 
-    if (uid.startsWith(QLatin1String("event:"))) {
-        item = cal->item(uid.mid(6));
-    } else if (uid.startsWith(QLatin1String("todo:"))) {
-        item = cal->item(uid.mid(5));
+    auto calendar = calendarForCollection(*calendarId);
+    if (!calendar) {
+        qCWarning(CALENDARVIEW_LOG) << "Calendar for collection " << *calendarId << " not present in current view";
+        return;
     }
 
-    if (item.isValid()) {
-        Q_EMIT showIncidenceSignal(item);
+    auto item = calendar->item(*itemId);
+    if (!item.isValid()) {
+        qCWarning(CALENDARVIEW_LOG) << "Item " << *itemId << " not found in collection " << *calendarId;
+        return;
     }
+
+    Q_EMIT showIncidenceSignal(item);
 }
+
+#include "moc_whatsnextview.cpp"
